/* APBasicLevel.m
 *
 * Copyright (C) 1999-2005 by vhf interservice GmbH
 * Author: Georg Fleischmann
 *
 * Created:  1996-03-03
 * Modified: 2003-03-29
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the vhf Public License as
 * published by vhf interservice GmbH. Among other things, the
 * License requires that the copyright notices and this notice
 * be preserved on all copies.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the vhf Public License for more details.
 *
 * You should have received a copy of the vhf Public License along
 * with this program; see the file LICENSE. If not, write to vhf.
 *
 * vhf interservice GmbH, Im Marxle 3, 72119 Altingen, Germany
 * eMail: info@vhf.de
 * http://www.vhf.de
 */

#include "APBasicLevel.h"
#include "AstroPanel.h"		// activeWindow

@implementation APBasicLevel

- init
{
    [self setDelegate:self];
    return self;
}

- (void)setWindow:win
{
    window = win; 
}

- window
{
    return window;
}

- (NSString*)name
{
    return @"None";
}

- (void)update:sender
{
}

- (BOOL)isActive
{
    return (self == [window activeWindow]) ? YES : NO;
}

/* delegate methods
 */
- (void)displayWillEnd
{
}

@end
